@@ -15,6 +15,9 @@ try:
     from . import command
     from . import check_value
     from . import version
+
+    from . import _api_post
+    from . import _api_get_time
 except ModuleNotFoundError:
     import data_type
     import config
@@ -28,6 +31,9 @@ except ModuleNotFoundError:
     import check_value
     import version
 
+    import _api_post
+    import _api_get_time
+
 
 class API:
     def __init__(
@@ -51,16 +57,18 @@ class API:
             has_log_handler = True
             set_log_handler_result = True
             try:
-                log_handler(f'PyPtt v {version.V}')
-                log_handler('Developed by CodingMan')
+                if log_level != log.level.SILENT:
+                    log_handler(f'PyPtt v {version.V}')
+                    log_handler('Developed by CodingMan')
             except TypeError:
                 log_handler = None
                 set_log_handler_result = False
         else:
             has_log_handler = False
 
-        print(f'PyPtt v {version.V}')
-        print('Developed by CodingMan')
+        if log_level != log.level.SILENT:
+            print(f'PyPtt v {version.V}')
+            print('Developed by CodingMan')
 
         self._login_status = False
         self.unregistered_user = True
@@ -77,8 +85,8 @@ class API:
             raise TypeError('[PyPtt] screen_timeout must be integer')
         if not isinstance(screen_long_timeout, int):
             raise TypeError('[PyPtt] screen_long_timeout must be integer')
-        if not isinstance(host, int):
-            raise TypeError('[PyPtt] host must be integer')
+        if (not isinstance(host, int)) and (not isinstance(host, str)):
+            raise TypeError('[PyPtt] host must be integer or string')
 
         if screen_timeout != 0:
             self.config.screen_timeout = screen_timeout
@@ -133,27 +141,15 @@ class API:
                     i18n.languageModule
                 ],
                 i18n.Init)
-        check_value.check(self.config, int, 'connect_mode', connect_mode)
-        if connect_mode == 0:
-            connect_mode = self.config.connect_mode
-        elif not lib_util.check_range(connect_core.connect_mode, connect_mode):
-            raise ValueError('[PyPtt] Unknown connect_mode', connect_mode)
-        else:
-            self.config.connect_mode = connect_mode
 
-        check_value.check(self.config, int, 'port', port)
-        if port == 0:
-            port = self.config.port
-        elif not 0 < port < 65535:
-            raise ValueError('[PyPtt] Unknown port', port)
-        else:
-            self.config.port = port
-
-        check_value.check(self.config, int, 'host', host)
-        if host == 0:
-            host = self.config.host
-        elif not lib_util.check_range(data_type.host_type, host):
-            raise ValueError('[PyPtt] Unknown host', host)
+        ##################
+        if isinstance(host, int):
+            if host == 0:
+                host = self.config.host
+            elif not lib_util.check_range(data_type.host_type, host):
+                raise ValueError('[PyPtt] Unknown host', host)
+        # elif isinstance(host, str):
+        #     pass
         self.config.host = host
 
         if self.config.host == data_type.host_type.PTT1:
@@ -183,6 +179,39 @@ class API:
                     i18n.host
                 ],
                 i18n.Localhost)
+        else:
+            log.show_value(
+                self.config,
+                log.level.INFO,
+                [
+                    i18n.Connect,
+                    i18n.host
+                ],
+                self.config.host)
+        ##################
+
+        if isinstance(host, int):
+            connect_core.connect_mode.min_value = connect_core.connect_mode.WEBSOCKET
+            connect_core.connect_mode.max_value = connect_core.connect_mode.WEBSOCKET
+        elif isinstance(host, str):
+            connect_core.connect_mode.min_value = connect_core.connect_mode.TELNET
+            connect_core.connect_mode.max_value = connect_core.connect_mode.WEBSOCKET
+
+        check_value.check(self.config, int, 'connect_mode', connect_mode)
+        if connect_mode == 0:
+            connect_mode = self.config.connect_mode
+        elif not lib_util.check_range(connect_core.connect_mode, connect_mode):
+            raise ValueError('[PyPtt] Unknown connect_mode', connect_mode)
+        else:
+            self.config.connect_mode = connect_mode
+
+        check_value.check(self.config, int, 'port', port)
+        if port == 0:
+            port = self.config.port
+        elif not 0 < port < 65535:
+            raise ValueError('[PyPtt] Unknown port', port)
+        else:
+            self.config.port = port
 
         self.connect_core = connect_core.API(self.config)
         self._exist_board_list = list()
@@ -292,6 +321,7 @@ class API:
         current_msg = ' '.join(msg)
         log.log(self.config, log.level.OUTSIDE, current_msg)
 
+
     def get_time(self) -> str:
         self._one_thread()
         if not self._login_status:
@@ -299,11 +329,6 @@ class API:
 
         self.config.log_last_value = None
 
-        try:
-            from . import _api_get_time
-        except ModuleNotFoundError:
-            import _api_get_time
-
         return _api_get_time.get_time(self)
 
     def get_post(
@@ -416,6 +441,7 @@ class API:
                         'PostIndex',
                         i18n.ErrorParameter,
                         i18n.OutOfRange,
+                        f'0 ~ {newest_index} but get {post_index}'
                     ]))
 
         self._check_board(board)
@@ -949,6 +975,9 @@ class API:
             sign_file) -> None:
         self._one_thread()
 
+        if self.unregistered_user:
+            raise exceptions.UnregisteredUser(lib_util.get_current_func_name())
+
         if not self._login_status:
             raise exceptions.Requirelogin(i18n.Requirelogin)
 
@@ -1000,6 +1029,9 @@ class API:
             post_index: int = 0) -> None:
         self._one_thread()
 
+        if self.unregistered_user:
+            raise exceptions.UnregisteredUser(lib_util.get_current_func_name())
+
         if not self._login_status:
             raise exceptions.Requirelogin(i18n.Requirelogin)
 
@@ -1096,7 +1128,7 @@ class API:
             index = 0
             jump = 0
 
-            while len(push_content[:index].encode('big5-uao', 'replace')) < max_push_length:
+            while len(push_content[:index].encode('big5uao', 'replace')) < max_push_length:
 
                 if index == len(push_content):
                     break
@@ -1524,7 +1556,7 @@ class API:
         except ModuleNotFoundError:
             import _api_mark_post
 
-        _api_mark_post.markPost(
+        _api_mark_post.mark_post(
             self,
             mark_type,
             board,
@@ -1793,6 +1825,9 @@ class API:
             post_index: int = 0) -> None:
         self._one_thread()
 
+        if self.unregistered_user:
+            raise exceptions.UnregisteredUser(lib_util.get_current_func_name())
+
         if not self._login_status:
             raise exceptions.Requirelogin(i18n.Requirelogin)
 
@@ -1920,6 +1955,26 @@ class API:
 
             self.connect_core.send(cmd, target_list)
 
+    def fast_post_step0(
+            self,
+            board: str,
+            title: str,
+            content: str,
+            post_type: int
+    ):
+        _api_post.fast_post_step0(
+            self,
+            board,
+            title,
+            content,
+            post_type)
+
+    def fast_post_step1(
+            self,
+            sign_file
+    ):
+        _api_post.fast_post_step1(self, sign_file)
+
 
 if __name__ == '__main__':
     print('PyPtt v ' + version.V)
